@@ -2,7 +2,9 @@
 
 __author__ = """Carlos Peralta"""
 __email__ = 'carlos9917@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 from hartools.hario.vobs import vobs
+#from hartools.harmon.config import config
+from hartools.harmon.log_timestamps import log_timestamps
 
